# coding: latin-1
# **************************************************************************
# *
# * Authors:     J.M. De la Rosa Trevin (delarosatrevin@scilifelab.se)
# *
# * SciLifeLab, Stockholm University
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 3 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

"""
@article{Heymann2007,
title = "Bsoft: Image processing and molecular modeling for electron microscopy ",
journal = "Journal of Structural Biology ",
volume = "157",
number = "1",
pages = "3 - 18",
year = "2007",
issn = "1047-8477",
doi = "http://dx.doi.org/10.1016/j.jsb.2006.06.006",
url = "http://www.sciencedirect.com/science/article/pii/S1047847706001997",
author = "J. Bernard Heymann and David M. Belnap",
keywords = "Single particle analysis Tomography",
}

@article{Cardone2013,
title = "One number does not fit all: mapping local variations in resolution in cryo-EM reconstructions",
journal = "Journal of Structural Biology",
volume = "184",
number = "2",
pages = "226 - 236",
year = "2013",
issue = "2",
doi = "http://dx.doi.org/10.1016/j.jsb.2013.08.002",
url = "http://www.sciencedirect.com/science/article/pii/S1047847713002086",
author = "Giovanni Cardone and Bernard Heymann and Alasdair Steven",
}

@article{Heymann2018,
title = "Guidelines for using Bsoft for high resolution reconstruction and validation of biomolecular structures from electron micrographs",
journal = "Protein Sci.",
volume = "27",
number = "1",
pages = "159 - 171",
year = "2018",
doi = "https://doi.org/10.1002/pro.3293",
url = "https://onlinelibrary.wiley.com/doi/full/10.1002/pro.3293",
author = "J. Bernard Heymann",
}

"""
